==> apache-geode-1.4.0-src.zip: apache-geode-1.4.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/backup/FlushToDiskFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.backup;

import java.util.Set;

import org.apache.geode.distributed.internal.DM;
import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
import org.apache.geode.internal.cache.InternalCache;

class FlushToDiskFactory {

  FlushToDiskProcessor createReplyProcessor(DM dm, Set<InternalDistributedMember> recipients) {
    return new FlushToDiskProcessor(dm, recipients);
  }

  FlushToDiskRequest createRequest(InternalDistributedMember sender,
      Set<InternalDistributedMember> recipients, int processorId) {
    return new FlushToDiskRequest(sender, recipients, processorId, this);
  }

  FlushToDisk createFlushToDisk(InternalCache cache) {
    return new FlushToDisk(cache);
  }

  FlushToDiskResponse createResponse(InternalDistributedMember sender) {
    return new FlushToDiskResponse(sender);
  }

}

==> apache-geode-1.5.0-src.zip: apache-geode-1.5.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/backup/FlushToDiskFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.backup;

import java.util.Set;

import org.apache.geode.distributed.internal.DistributionManager;
import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
import org.apache.geode.internal.cache.InternalCache;

class FlushToDiskFactory {

  FlushToDiskProcessor createReplyProcessor(DistributionManager dm,
      Set<InternalDistributedMember> recipients) {
    return new FlushToDiskProcessor(dm, recipients);
  }

  FlushToDiskRequest createRequest(InternalDistributedMember sender,
      Set<InternalDistributedMember> recipients, int processorId) {
    return new FlushToDiskRequest(sender, recipients, processorId, this);
  }

  FlushToDisk createFlushToDisk(InternalCache cache) {
    return new FlushToDisk(cache);
  }

  FlushToDiskResponse createResponse(InternalDistributedMember sender) {
    return new FlushToDiskResponse(sender);
  }

}
